@@ -11,6 +11,11 @@ import publication
 import aws_cdk.core
 import aws_cdk.region_info
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-iam", "1.33.0", __name__[0:-6], "aws-iam@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
